<?php

if ( !class_exists('gs_Courses_Settings_Config' ) ):
class gs_Courses_Settings_Config {

    private $settings_api;

    function __construct() {
        $this->settings_api = new gs_Courses_WeDevs_Settings_API;

        add_action( 'admin_init', array($this, 'admin_init') ); //display options
        add_action( 'admin_menu', array($this, 'admin_menu') ); //display the page of options.
    }

    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->get_settings_sections() );
        $this->settings_api->set_fields( $this->get_settings_fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function admin_menu() {

        add_submenu_page( 'edit.php?post_type=gs_courses', 'Courses Settings', 'Courses Settings', 'delete_posts', 'courses-settings', array($this, 'plugin_page'));
    }


    function get_settings_sections() {
        $sections = array(
            array(
                'id'     => 'gs_courses_option_01_settings',
                'title' => __( 'Course Page Settings', 'gscourses' )
            ),
            array(
                'id'     => 'gs_courses_option_02_settings',
                'title' => __( 'Course Settings', 'gscourses' )
            ),
            array(
                'id'    => 'gs_courses_style_settings',
                'title' => __( 'Style Settings', 'gscourses' )
            ),
             array(
                'id'    => 'gs_courses_adv_settings',
                'title' => __( 'Advanced Settings', 'gscourses' )
            )
        );
        return $sections;
    }

    //start all options of "GS course settings" and "Style Settings" under nav
    /*
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_settings_fields() {
        $settings_fields = array(
            'gs_courses_option_01_settings' => array(
                // Front page display Columns
                array(
                    'name'      => 'gs_courses_cols',
                    'label'     => __( 'Page Columns', 'gscourses' ),
                    'desc'      => __( 'Select number of Course Showcase columns', 'gscourses' ),
                    'type'      => 'select',
                    'default'   => '3',
                    'options'   => array(
                        '6'    => '2 Columns',
                        '4'      => '3 Columns',
                        '3'      => '4 Columns',
                    )
                ),
                // courses theme
                array(
                    'name'  => 'gs_courses_theme',
                    'label' => __( 'Style & Theming', 'gscourses' ),
                    'desc'  => __( 'Select preffered Style & Theme', 'gscourses' ),
                    'type'  => 'select',
                    'default'   => 'gs_course_grid_1',
                    'options'   => array(
                        'gs_course_grid_1'           => 'Grid 1',
                        'gs_course_horizontal_1'     => 'Horizontal (Right Info)',
                        'gs_course_horizontal_2'     => 'Horizontal (Left Info)',
                        'gs_course_list_1'           => 'List (Right Info)',
                        'gs_course_list_2'           => 'List (Left Info)',
                        'gs_course_card_1'           => 'Card (Bottom Info)',
                        'gs_course_slider_1'         => 'Slider',
                        'gs_course_popup_1'          => 'Popup',
                        'gs_course_filter_1'         => 'Filter',
                    )
                ),
                // Course Link Target
                array(
                    'name'      => 'gs_course_link_tar',
                    'label'     => __( 'Course Link Target', 'gscourses' ),
                    'desc'      => __( 'Specify target to load the Links, Default New Tab ', 'gscourses' ),
                    'type'      => 'select',
                    'default'   => '_blank',
                    'options'   => array(
                        '_blank'    => 'New Tab',
                        '_self'     => 'Same Window'
                    )
                ),
                // Course Detail Description character control
                array(
                    'name'  => 'gs_course_details_contl',
                    'label' => __( 'Details Character Control', 'gscourses' ),
                    'desc'  => __( 'Define maximum number of characters in Course details. Default 100 & Maximum 300', 'gscourses' ),
                    'type'  => 'number',
                    'min'   => 1,
                    'max'   => 300,
                    'default' => 100
                )
            ), // end of Course Settings nav, 'gs_courses_option_01_settings'
            // Start of course settings nav, 'gs_courses_option_02_settings'
            'gs_courses_option_02_settings' => array(
                // course Name
                array(
                    'name'      => 'gs_course_title',
                    'label'     => __( 'Course Name', 'gscourses' ),
                    'desc'      => __( 'Show or Hide All Courses Name', 'gscourses' ),
                    'type'      => 'switch',
                    'switch_default' => 'ON'
                ),
                // Course Description/Details
                array(
                    'name'      => 'gs_course_details',
                    'label'     => __( 'Course Details', 'gscourses' ),
                    'desc'      => __( 'Show or Hide All Courses Details', 'gscourses' ),
                    'type'      => 'switch',
                    'switch_default' => 'ON'
                ),
                // Course rating
                array(
                    'name'      => 'gs_course_rating',
                    'label'     => __( 'Course Rating', 'gscourses' ),
                    'desc'      => __( 'Show or Hide All Courses rating', 'gscourses' ),
                    'type'      => 'switch',
                    'switch_default' => 'ON'
                )
            ), // end of Course Settings nav, 'gs_courses_option_02_settings'

            // start of Style Settings nav array, 'gs_courses_style_settings'
            'gs_courses_style_settings' => array(
                // Font Size
                array(
                    'name'      => 'gs_course_fz',
                    'label'     => __( 'Font Size', 'gscourses' ),
                    'desc'      => __( 'Set Font Size for <b>Course Name</b>', 'gscourses' ),
                    'type'      => 'number',
                    'default'   => '14',
                    'options'   => array(
                        'min'   => 1,
                        'max'   => 30,
                        'default' => 17
                    )
                ),
                // Font weight
                array(
                    'name'      => 'gs_course_fntw',
                    'label'     => __( 'Font Weight', 'gscourses' ),
                    'desc'      => __( 'Select Font Weight for <b>Course Name</b>', 'gscourses' ),
                    'type'      => 'select',
                    'default'   => 'normal',
                    'options'   => array(
                        'normal'    => 'Normal',
                        'bold'      => 'Bold',
                        'lighter'   => 'Lighter'
                    )
                ),
                // Font style
                array(
                    'name'      => 'gs_course_fnstyl',
                    'label'     => __( 'Font Style', 'gscourses' ),
                    'desc'      => __( 'Select Font Weight for <b>Course Name</b>', 'gscourses' ),
                    'type'      => 'select',
                    'default'   => 'normal',
                    'options'   => array(
                        'normal'    => 'Normal',
                        'italic'      => 'Italic'
                    )
                ),
                // Font Color of Course Name
                array(
                    'name'    => 'gs_course_name_color',
                    'label'   => __( 'Font Color', 'gscourses' ),
                    'desc'    => __( 'Select color for <b>Course Name</b>.', 'gscourses' ),
                    'type'    => 'color',
                    'default' => '#141412'
                ),
                // Label Font Size
                array(
                    'name'      => 'gs_course_label_fz',
                    'label'     => __( 'Label Font Size', 'gscourses' ),
                    'desc'      => __( 'Set Font Size for <b>Course Label</b>', 'gscourses' ),
                    'type'      => 'number',
                    'default'   => '18',
                    'options'   => array(
                        'min'   => 1,
                        'max'   => 30,
                        'default' => 18
                    )
                ),
                // Label Font Color
                array(
                   'name'    => 'gs_course_label_color',
                   'label'   => __( 'Label Font Color', 'gscourses' ),
                   'desc'    => __( 'Select color for <b>Course Label</b>.', 'gscourses' ),
                   'type'    => 'color',
                   'default' => '#00bbff'
                ),
                // Filter name Align
                array(
                   'name'    => 'gs_course_filter_align',
                   'label'   => __( 'Filter Name Align', 'gscourses' ),
                   'desc'    => __( 'Filter name alignment for <b> Filter Theme</b>.', 'gscourses' ),
                   'type'      => 'select',
                    'default'   => 'center',
                    'options'   => array(
                        'center'    => 'Align Center',
                        'left'  => 'Align Left',
                        'right' => 'Align Right'
                    )
                ),
                // All filter Name
                array(
                   'name'    => 'gs_course_filter_name',
                   'label'   => __( 'All Filter Name', 'gscourses' ),
                   'desc'    => __( 'All filter name for <b> Filter Index</b>.', 'gscourses' ),
                    'default'   => 'All',
                    'type'    => 'text'
                ),
                // courses Custom CSS
                array(
                    'name'    => 'gs_course_custom_css',
                    'label'   => __( 'Course Custom CSS', 'gscourses' ),
                    'desc'    => __( 'You can write your own custom css', 'gscourses' ),
                    'type'    => 'textarea'
                ),
            ), // end of Style Settings nav array, 'gs_courses_style_settings'
            'gs_courses_adv_settings' => array(
                // GS Books Showcase Slug
                array(
                    'name'      => 'gs_courses_slug',
                    'label'     => __( 'courses Slug', 'gscourses' ),
                    'desc'      => __( 'After updating GS courses slug, single Course may NOT found with 404 error. In this senario make sure to Flush Rewrite Rules.To Flush, please change permalink structure at Settings > Permalinks then select any option instead of current option... click save change. Clear cache if needed. You can back to your previous Permalinks structure again.', 'gscourses' ),
                    'type'      => 'text',
                    'default'   => 'course'
                )
            )
        ); //end of $settings_fields
        return $settings_fields;
    } // end of function get_settings_fields()

    function plugin_page() {
        settings_errors();
        echo '<div class="wrap gs_courses_wrap" style="width: 845px; float: left;">';
        // echo '<div id="post-body-content">';

        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();

        echo '</div>';

        ?>
            <div class="gswps-admin-sidebar" style="width: 277px; float: left; margin-top: 62px;">
                <div class="postbox">
                    <h3 class="hndle"><span><?php _e( 'Support / Report a bug' ) ?></span></h3>
                    <div class="inside centered">
                        <p>Please feel free to let me know if you got any bug to report. Your report / suggestion can make the plugin awesome!</p>
                        <p style="margin-bottom: 1px! important;"><a href="https://www.gsamdani.com/support" target="_blank" class="button button-primary">Get Support</a></p>
                    </div>
                </div>
                <div class="postbox">
                    <h3 class="hndle"><span><?php _e( 'Buy me a coffee' ) ?></span></h3>
                    <div class="inside centered">
                        <p>If you like the plugin, please buy me a coffee to inspire me to develop further.</p>
                        <p style="margin-bottom: 1px! important;"><a href='https://www.2checkout.com/checkout/purchase?sid=202460873&quantity=1&product_id=8' class="button button-primary" target="_blank">Donate</a></p>
                    </div>
                </div>

                <div class="postbox">
                    <h3 class="hndle"><span><?php _e( 'Join GS Plugins on facebook' ) ?></span></h3>
                    <div class="inside centered">
                        <iframe src="//www.facebook.com/plugins/likebox.php?href=https://www.facebook.com/gsplugins&amp;width&amp;height=258&amp;colorscheme=dark&amp;show_faces=true&amp;header=false&amp;stream=false&amp;show_border=false&amp;appId=723137171103956" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:250px; height:220px;" allowTransparency="true"></iframe>
                    </div>
                </div>

                <div class="postbox">
                    <h3 class="hndle"><span><?php _e( 'Follow GS Plugins on twitter' ) ?></span></h3>
                    <div class="inside centered">
                        <a href="https://twitter.com/gsplugins" target="_blank" class="button button-secondary">Follow @gsplugins<span class="dashicons dashicons-twitter" style="position: relative; top: 3px; margin-left: 3px; color: #0fb9da;"></span></a>
                    </div>
                </div>
            </div>
        <?php
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages = get_pages();
        $pages_options = array();
        if ( $pages ) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }

        return $pages_options;
    }

}
endif;

$settings = new gs_Courses_Settings_Config();
