<?php
/**
 * Repeatable Custom Fields in a Metabox
 * Author: Helen Hou-Sandi
 *
 * From a bespoke system, so currently not modular - will fix soon
 * Note that this particular metadata is saved as one multidimensional array (serialized)
 */

function gs_courses_get_sample_options() {
    $options = array (
        'Video' => 'Video',
        'Text' => 'Text',
    );

    return $options;
}

add_action('admin_init', 'gs_courses_add_meta_boxes', 1);
function gs_courses_add_meta_boxes() {
    add_meta_box( 'gs-courses-repeatable-fields', 'Syllabus', 'gs_courses_repeatable_meta_box_display', 'gs_courses', 'normal', 'default');
}

function gs_courses_repeatable_meta_box_display() {
    global $post;

    $repeatable_fields = get_post_meta($post->ID, 'repeatable_fields', true);
    $options = gs_courses_get_sample_options();

    wp_nonce_field( 'gs_courses_repeatable_meta_box_nonce', 'gs_courses_repeatable_meta_box_nonce' );
    ?>
    <script type="text/javascript">
    jQuery(document).ready(function( $ ){
        $( '#add-row' ).on('click', function() {
            var row = $( '.empty-row.screen-reader-text' ).clone(true);
            row.removeClass( 'empty-row screen-reader-text' );
            row.insertBefore( '#gs-courses-repeatable-fieldset-one tbody>tr:last' );
            return false;
        });

        $( '.remove-row' ).on('click', function() {
            $(this).parents('tr').remove();
            return false;
        });
    });
    </script>

    <table id="gs-courses-repeatable-fieldset-one" width="100%">
    <thead>
        <tr>
            <th width="50%">Items</th>
            <th width="10%">Quantity</th>
            <th width="15%">Video/Text</th>
            <th width="15%">Duration/Hours</th>
            <th width="10%"></th>
        </tr>
    </thead>
    <tbody>
    <?php

    if ( $repeatable_fields ) :

    foreach ( $repeatable_fields as $field ) {
    ?>
    <tr>
        <td><input type="text" class="widefat" name="name[]" value="<?php if($field['name'] != '') echo esc_attr( $field['name'] ); ?>" /></td>
        <td><input type="text" class="widefat" name="quantity[]" value="<?php if($field['quantity'] != '') echo esc_attr( $field['quantity'] ); ?>" /></td>

        <td>
            <select name="select[]" style="width:100%">
            <?php foreach ( $options as $label => $value ) : ?>
            <option value="<?php echo $value; ?>"<?php selected( $field['select'], $value ); ?>><?php echo $label; ?></option>
            <?php endforeach; ?>
            </select>
        </td>

        <td><input type="text" class="widefat" name="duration[]" value="<?php if ($field['duration'] != '') echo esc_attr( $field['duration'] ); else echo '-'; ?>" /></td>

        <td><a class="button remove-row" href="#">Remove</a></td>
    </tr>
    <?php
    }
    else :
    // show a blank one
    ?>
    <tr>
        <td><input type="text" class="widefat" name="name[]" /></td>
        <td><input type="text" class="widefat" name="quantity[]" /></td>

        <td>
            <select name="select[]" style="width:100%">
            <?php foreach ( $options as $label => $value ) : ?>
            <option value="<?php echo $value; ?>"><?php echo $label; ?></option>
            <?php endforeach; ?>
            </select>
        </td>

        <td><input type="text" class="widefat" name="duration[]" value="" /></td>

        <td><a class="button remove-row" href="#">Remove</a></td>
    </tr>
    <?php endif; ?>

    <!-- empty hidden one for jQuery -->
    <tr class="empty-row screen-reader-text">
        <td><input type="text" class="widefat" name="name[]" /></td>
        <td><input type="text" class="widefat" name="quantity[]" /></td>

        <td>
            <select name="select[]" style="width:100%">
            <?php foreach ( $options as $label => $value ) : ?>
            <option value="<?php echo $value; ?>"><?php echo $label; ?></option>
            <?php endforeach; ?>
            </select>
        </td>

        <td><input type="text" class="widefat" name="duration[]" value="" /></td>

        <td><a class="button remove-row" href="#">Remove</a></td>
    </tr>
    </tbody>
    </table>

    <p><a id="add-row" class="button" href="#">Add New Item</a></p>
    <?php
}

add_action('save_post', 'gs_courses_repeatable_meta_box_save');
function gs_courses_repeatable_meta_box_save($post_id) {
    if ( ! isset( $_POST['gs_courses_repeatable_meta_box_nonce'] ) ||
    ! wp_verify_nonce( $_POST['gs_courses_repeatable_meta_box_nonce'], 'gs_courses_repeatable_meta_box_nonce' ) )
        return;

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;

    if (!current_user_can('edit_post', $post_id))
        return;

    $old = get_post_meta($post_id, 'repeatable_fields', true);
    $new = array();
    $options = gs_courses_get_sample_options();

    $names = $_POST['name'];
    $quantitys = $_POST['quantity'];
    $selects = $_POST['select'];
    $durations = $_POST['duration'];

    $count = count( $names );

    for ( $i = 0; $i < $count; $i++ ) {
        if ( $names[$i] != '' ) :
            $new[$i]['name'] = stripslashes( strip_tags( $names[$i] ) );

            if ( $quantitys[$i] == '' )
                $new[$i]['quantity'] = '';
            else
                $new[$i]['quantity'] = stripslashes( strip_tags( $quantitys[$i] ) );

            if ( in_array( $selects[$i], $options ) )
                $new[$i]['select'] = $selects[$i];
            else
                $new[$i]['select'] = '';

            if ( $durations[$i] == '' )
                $new[$i]['duration'] = '';
            else
                $new[$i]['duration'] = stripslashes( $durations[$i] ); // and however you want to sanitize
        endif;
    }

    if ( !empty( $new ) && $new != $old )
        update_post_meta( $post_id, 'repeatable_fields', $new );
    elseif ( empty($new) && $old )
        delete_post_meta( $post_id, 'repeatable_fields', $old );
}

?>