<?php
/**
* Registers a new post type
* @uses $wp_post_types Inserts new post type object into the list
*
* @param string  Post type key, must not exceed 20 characters
* @param array|string  See optional args description above.
* @return object|WP_Error the registered post type object, or an error object
*/
/*
course  courses
*/

//Registers a new post type
if ( ! function_exists( 'GS_Courses' ) ) {
    function GS_Courses() {
        $labels = array(
            'name'               => _x( 'Course', 'gscourses' ),
            'singular_name'      => _x( 'Course', 'gscourses' ),
            'menu_name'          => _x( 'GS Course', 'admin menu', 'gscourses' ),
            'name_admin_bar'     => _x( 'GS Course', 'add new on admin bar', 'gscourses' ),
            'add_new'            => _x( 'Add New Course', 'course', 'gscourses' ),
            'add_new_item'       => __( 'Add New Course', 'gscourses' ),
            'new_item'           => __( 'New Course', 'gscourses' ),
            'edit_item'          => __( 'Edit Course', 'gscourses' ),
            'view_item'          => __( 'View Course', 'gscourses' ),
            'all_items'          => __( 'All Courses', 'gscourses' ),
            'search_items'       => __( 'Search Course', 'gscourses' ),
            'parent_item_colon'  => __( 'Parent Course:', 'gscourses' ),
            'not_found'          => __( 'No Course found.', 'gscourses' ),
            'not_found_in_trash' => __( 'No Course found in Trash.', 'gscourses' ),
        );
        if( $status !== false && $status == 'valid' ) {
            $gscourse_op_slug     = gs_courses_getoption('gs_courses_slug', 'gs_courses_adv_settings', 'course');
        }
        
        $args = array(
            'labels'             => $labels,
            'public'             => true,
            'publicly_queryable' => true,
            'show_ui'            => true,
            'show_in_menu'       => true,
            'query_var'          => true,
            'rewrite'            => array( 'slug' => $gscourse_op_slug ), //this slug is for post path/permalink
            'capability_type'    => 'post',
            'has_archive'        => true,
            'hierarchical'       => false,
            'menu_position'      => GSCOURSES_MENU_POSITION,
            'menu_icon'          => 'dashicons-welcome-learn-more',
            'supports'           => array( 'title', 'editor','thumbnail'),
        );
        register_post_type( 'gs_courses', $args );
    }
}
add_action( 'init', 'GS_Courses' );

// =============taxonomy==================
if ( ! function_exists( 'gs_courses_group' ) ) {
// Register Custom Taxonomy For course
function gs_courses_group() {
    $labels = array(
        'name'                       => _x( 'Course Group/Category', 'Taxonomy General Name', 'gscourses' ),
        'singular_name'              => _x( 'Course Group', 'Taxonomy Singular Name', 'gscourses' ),
        'menu_name'                  => __( 'Course Group', 'gscourses' ),
        'all_items'                  => __( 'All Course Group/Category', 'gscourses' ),
        'parent_item'                => __( 'Parent Course Group', 'gscourses' ),
        'parent_item_colon'          => __( 'Parent Course Group:', 'gscourses' ),
        'new_item_name'              => __( 'New Course Group', 'gscourses' ),
        'add_new_item'               => __( 'Add New Course Group/Category', 'gscourses' ),
        'edit_item'                  => __( 'Edit Course Group', 'gscourses' ),
        'update_item'                => __( 'Update Course Group', 'gscourses' ),
        'separate_items_with_commas' => __( 'Separate Course Group with commas', 'gscourses' ),
        'search_items'               => __( 'Search Course Group', 'gscourses' ),
        'add_or_remove_items'        => __( 'Add or Remove Course Group', 'gscourses' ),
        'choose_from_most_used'      => __( 'Choose from the most used Course Groups', 'gscourses' ),
        'not_found'                  => __( 'Not Found', 'gscourses' ),
    );
    $rewrite = array(
        'slug'                       => 'gs-courses-group',
        'with_front'                 => true,
        'hierarchical'               => false,
    );
    $args = array(
        'labels'                     => $labels,
        'hierarchical'               => true,
        'public'                     => true,
        'show_ui'                    => true,
        'show_admin_column'          => true,
        'show_in_nav_menus'          => false,
        'show_tagcloud'              => false,
        'rewrite'                    => $rewrite,
    );
    register_taxonomy( 'courses_group', array( 'gs_courses' ), $args );
}
add_action( 'init', 'gs_courses_group', 0 );
}


// =============taxonomy : Sub-Category ==================
if ( ! function_exists( 'gs_courses_subcategory' ) ) {
// Register Custom Taxonomy For course
function gs_courses_subcategory() {
    $labels = array(
        'name'                       => _x( 'Sub Category', 'Taxonomy General Name', 'gscourses' ),
        'singular_name'              => _x( 'Sub Category', 'Taxonomy Singular Name', 'gscourses' ),
        'menu_name'                  => __( 'Sub Category', 'gscourses' ),
        'all_items'                  => __( 'All Sub Category', 'gscourses' ),
        'parent_item'                => __( 'Parent Sub Category', 'gscourses' ),
        'parent_item_colon'          => __( 'Parent Sub Category:', 'gscourses' ),
        'new_item_name'              => __( 'New Sub Category', 'gscourses' ),
        'add_new_item'               => __( 'Add New Sub Category', 'gscourses' ),
        'edit_item'                  => __( 'Edit Sub Category', 'gscourses' ),
        'update_item'                => __( 'Update Sub Category', 'gscourses' ),
        'separate_items_with_commas' => __( 'Separate Sub Category with commas', 'gscourses' ),
        'search_items'               => __( 'Search Sub Category', 'gscourses' ),
        'add_or_remove_items'        => __( 'Add or remove Sub Category', 'gscourses' ),
        'choose_from_most_used'      => __( 'Choose from the most used Sub Category', 'gscourses' ),
        'not_found'                  => __( 'Not Found', 'gscourses' ),
    );
    $rewrite = array(
        'slug'                       => 'gs-subcategory',
        'with_front'                 => true,
        'hierarchical'               => false,
    );
    $args = array(
        'labels'                     => $labels,
        'hierarchical'               => true,
        'public'                     => true,
        'show_ui'                    => true,
        'show_admin_column'          => true,
        'show_in_nav_menus'          => false,
        'show_tagcloud'              => false,
        'rewrite'                    => $rewrite,
    );
    register_taxonomy( 'subcategory_group', array( 'gs_courses' ), $args );
}
add_action( 'init', 'gs_courses_subcategory', 0 );
}


// Register Theme Features (feature image for course)
if ( ! function_exists('gs_courses_theme_support') ) {

    function gs_courses_theme_support()  {
        // Add theme support for Featured Images
        add_theme_support( 'post-thumbnails', array( 'gs_courses' ) );
        add_theme_support( 'post-thumbnails', array( 'post' ) );
        add_theme_support( 'post-thumbnails', array( 'page' ) );
        add_theme_support( 'post-thumbnails', array( 'product' ) );
        add_theme_support( 'post-thumbnails');
        // Add Shortcode support in text widget
        add_filter('widget_text', 'do_shortcode');
    }
    // Hook into the 'after_setup_theme' action
    add_action( 'after_setup_theme', 'gs_courses_theme_support' );
}