<?php

/**
 * Adds GSCOURSES_Widget widget.
 */
class GSCOURSES_Widget extends WP_Widget {
    /**
     * Register widget with WordPress.
     */
    function __construct() {
        parent::__construct(
            'GSCOURSE_widget', // Base ID
            __( 'GS Courses', 'gscourses' ), // Name
            array( 'description' => __( 'Display GS Courses at Widget Area.', 'gscourses' ), ) // Args
        );
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {

        extract($instance);
// print_r($instance);
        $title = ! empty( $instance['title'] ) ? $instance['title'] : __( 'Latest Courses', 'gscourses' );
        $num_course = ! empty( $instance['num_course'] ) ? $instance['num_course'] : 3;
        $group_course = ! empty( $instance['group_course'] ) ? $instance['group_course'] : '';

        $gscourse_taxonomy = 'courses_group';
        $gscourse_term =  get_terms($gscourse_taxonomy);
        ?>

        <p>
        <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
        <input
            class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
            name="<?php echo $this->get_field_name( 'title' ); ?>"
            type="text" value="<?php if( isset($title) ) echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('num_course');?>">Total Courses to display :</label>
            <input style="" class="widefat" type="number" min="1"
                id="<?php echo $this->get_field_id('num_course');?>"
                name="<?php echo $this->get_field_name('num_course');?>"
                value="<?php if(isset($num_course)) echo esc_attr($num_course);?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('group_course'); ?>"><?php echo _e('Course Group / Category: ') ?></label>
            <select value="<?php echo esc_attr( $group_course ); ?>" class="widefat" name="<?php echo $this->get_field_name('group_course'); ?>" id="<?php echo $this->get_field_id('group_course'); ?>">

                <option <?php echo ($group_course == 'all') ? 'selected' : ''; ?> value="">All Groups</option>

                <?php foreach( $gscourse_term as $term) : ?>
                    <option <?php echo ( $group_course == $term->slug ) ? 'selected' : ''; ?> value="<?php echo $term->slug; ?>"><?php echo ucfirst($term->name); ?></option>
                <?php endforeach; ?>
            </select>
        </p>

        <?php
    }


    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        extract($args);
        extract($instance);

        echo $before_widget;
            echo $before_title . $title . $after_title;
            echo do_shortcode( '[gs_courses_sidebar num_course="'. $instance['num_course'] .'" group_course="'. $instance['group_course'] .'"]' );
        echo $after_widget;
    }

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['num_course'] = ( ! empty( $new_instance['num_course'] ) ) ? strip_tags( $new_instance['num_course'] ) : '';
        $instance['group_course'] = ( ! empty( $new_instance['group_course'] ) ) ? strip_tags( $new_instance['group_course'] ) : '';

        return $instance;
    }

} // class GSCOURSES_Widget

// register GSCOURSE_Widget widget
function register_GSCOURSES_widget() {
    register_widget( 'GSCOURSES_Widget' );
}
add_action( 'widgets_init', 'register_GSCOURSES_widget' );
